********************************************************
Protean: The Domain-Centric, Antifragile Framework
********************************************************

Protean helps you build software on architecture stacks that need to survive in the ever changing technology landscape.

.. image:: https://travis-ci.org/proteanhq/protean.svg?branch=master
    :target: https://travis-ci.org/proteanhq/protean
    :alt: Build Status
.. image:: https://codecov.io/gh/proteanhq/protean/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/proteanhq/protean
    :alt: Coverage
.. image:: https://pyup.io/repos/github/proteanhq/protean/shield.svg
     :target: https://pyup.io/repos/github/proteanhq/protean/
     :alt: Updates

Installation
############

::

    pip install protean

Documentation
#############

Online docs are available at: https://protean.readthedocs.io/en/latest/

How to Contribute
#################

1.  Check for open issues or open a fresh issue to start a discussion
    around a feature idea or a bug.
2.  Fork [the repository](https://github.com/proteanhq/protean) on
    GitHub to start making your changes to the **master** branch (or
    branch off of it).
3.  Write a test which shows that the bug was fixed or that the feature
    works as expected.
4.  Send a pull request and bug the maintainer until it gets merged and
    published. :) Make sure to add yourself to
    [AUTHORS](https://github.com/proteanhq/protean/blob/master/AUTHORS.rst).

On shoulders of giants...
#########################

Protean is not built in a vacuum. Principles and philosophies that Protean espouses are contributions from multiple sources, especially the Open Source Community. It not only refers to well-published architectural ideas and design patterns but also heavily draws inspiration from concrete implementations.

Specifically, Protean is majorly influenced by the venerable Django Framework, and that reflects in many aspects of its underlying constructs and documentation. Thank you, Django, and the Python community, for showing what's possible.

[ ~ Dependencies scanned by PyUp.io ~ ]
